@@ -32,7 +32,7 @@ class SignedDataForm(forms.Form):
         initial = kwargs.pop("initial", None)
         if initial:
             initial = {"signed": self.sign(initial)}
-        super(SignedDataForm, self).__init__(*args, initial=initial, **kwargs)
+        super().__init__(*args, initial=initial, **kwargs)
 
     def clean_signed(self):
         try:
@@ -48,7 +48,6 @@ class SignedDataForm(forms.Form):
 
     @classmethod
     def sign(cls, data):
-        # Sort the data by the keys to create a fixed ordering.
         items = sorted(data.items(), key=lambda item: item[0])
         return signing.Signer(salt=cls.salt).sign(
             json.dumps(OrderedDict((key, force_str(value)) for key, value in items))
