@@ -2,16 +2,10 @@
 Debug Toolbar middleware
 """
 
-from __future__ import absolute_import, unicode_literals
-
 import re
-import threading
+from functools import lru_cache
 
 from django.conf import settings
-from django.utils import six
-from django.utils.deprecation import MiddlewareMixin
-from django.utils.encoding import force_text
-from django.utils.lru_cache import lru_cache
 from django.utils.module_loading import import_string
 
 from debug_toolbar import settings as dt_settings
@@ -35,76 +29,41 @@ def get_show_toolbar():
     # If SHOW_TOOLBAR_CALLBACK is a string, which is the recommended
     # setup, resolve it to the corresponding callable.
     func_or_path = dt_settings.get_config()["SHOW_TOOLBAR_CALLBACK"]
-    if isinstance(func_or_path, six.string_types):
+    if isinstance(func_or_path, str):
         return import_string(func_or_path)
     else:
         return func_or_path
 
 
-class DebugToolbarMiddleware(MiddlewareMixin):
+class DebugToolbarMiddleware:
     """
     Middleware to set up Debug Toolbar on incoming request and render toolbar
     on outgoing response.
     """
 
-    debug_toolbars = {}
+    def __init__(self, get_response):
+        self.get_response = get_response
 
-    def process_request(self, request):
-        # Decide whether the toolbar is active for this request.
+    def __call__(self, request):
+        # Decide whether the toolbar is active for this request. Don't render
+        # the toolbar during AJAX requests.
         show_toolbar = get_show_toolbar()
-        if not show_toolbar(request):
-            return
+        if not show_toolbar(request) or request.is_ajax():
+            return self.get_response(request)
 
-        # Don't render the toolbar during AJAX requests.
-        if request.is_ajax():
-            return
-
-        toolbar = DebugToolbar(request)
-        self.__class__.debug_toolbars[threading.current_thread().ident] = toolbar
+        toolbar = DebugToolbar(request, self.get_response)
 
         # Activate instrumentation ie. monkey-patch.
         for panel in toolbar.enabled_panels:
             panel.enable_instrumentation()
-
-        # Run process_request methods of panels like Django middleware.
-        response = None
-        for panel in toolbar.enabled_panels:
-            response = panel.process_request(request)
-            if response:
-                break
-        return response
-
-    def process_view(self, request, view_func, view_args, view_kwargs):
-        toolbar = self.__class__.debug_toolbars.get(threading.current_thread().ident)
-        if not toolbar:
-            return
-
-        # Run process_view methods of panels like Django middleware.
-        response = None
-        for panel in toolbar.enabled_panels:
-            response = panel.process_view(request, view_func, view_args, view_kwargs)
-            if response:
-                break
-        return response
-
-    def process_response(self, request, response):
-        toolbar = self.__class__.debug_toolbars.pop(
-            threading.current_thread().ident, None
-        )
-        if not toolbar:
-            return response
-
-        # Run process_response methods of panels like Django middleware.
-        for panel in reversed(toolbar.enabled_panels):
-            new_response = panel.process_response(request, response)
-            if new_response:
-                response = new_response
-
-        # Deactivate instrumentation ie. monkey-unpatch. This must run
-        # regardless of the response. Keep 'return' clauses below.
-        # (NB: Django's model for middleware doesn't guarantee anything.)
-        for panel in reversed(toolbar.enabled_panels):
-            panel.disable_instrumentation()
+        try:
+            # Run panels like Django middleware.
+            response = toolbar.process_request(request)
+        finally:
+            # Deactivate instrumentation ie. monkey-unpatch. This must run
+            # regardless of the response. Keep 'return' clauses below.
+            for panel in reversed(toolbar.enabled_panels):
+                panel.disable_instrumentation()
 
         # Check for responses where the toolbar can't be inserted.
         content_encoding = response.get("Content-Encoding", "")
@@ -123,7 +82,7 @@ class DebugToolbarMiddleware(MiddlewareMixin):
             response.set_cookie("djdt", "hide", 864000)
 
         # Insert the toolbar in the response.
-        content = force_text(response.content, encoding=response.charset)
+        content = response.content.decode(response.charset)
         insert_before = dt_settings.get_config()["INSERT_BEFORE"]
         pattern = re.escape(insert_before)
         bits = re.split(pattern, content, flags=re.IGNORECASE)
@@ -153,9 +112,9 @@ class DebugToolbarMiddleware(MiddlewareMixin):
                 continue
 
             for key, record in stats.items():
-                # example: `SQLPanel_sql_time=0; "SQL 0 queries"`
+                # example: `SQLPanel_sql_time;dur=0;desc="SQL 0 queries"`
                 data.append(
-                    '{}_{}={}; "{}"'.format(
+                    '{}_{};dur={};desc="{}"'.format(
                         panel.panel_id, key, record.get("value"), record.get("title")
                     )
                 )
