@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 import json
 
 from django import forms
@@ -27,7 +25,7 @@ class SQLSelectForm(forms.Form):
     duration = forms.FloatField()
 
     def __init__(self, *args, **kwargs):
-        super(SQLSelectForm, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         for name in self.fields:
             self.fields[name].widget = forms.HiddenInput()
@@ -57,7 +55,7 @@ class SQLSelectForm(forms.Form):
         return value
 
     def reformat_sql(self):
-        return reformat_sql(self.cleaned_data["sql"])
+        return reformat_sql(self.cleaned_data["sql"], with_toggle=False)
 
     @property
     def connection(self):
