@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 from django.core import signing
 from django.http import HttpResponseBadRequest
 from django.template import Origin, TemplateDoesNotExist
@@ -46,7 +44,7 @@ def template_source(request):
         except TemplateDoesNotExist:
             pass
     else:
-        source = "Template Does Not Exist: %s" % (template_origin_name,)
+        source = "Template Does Not Exist: {}".format(template_origin_name)
 
     try:
         from pygments import highlight
