@@ -86,6 +86,7 @@ if os.environ.get("DJANGO_DATABASE_ENGINE", "").lower() == "postgresql":
 if os.environ.get("DJANGO_DATABASE_ENGINE", "").lower() == "mysql":
     # % mysql
     # mysql> CREATE DATABASE debug_toolbar;
+    # mysql> CREATE USER 'debug_toolbar'@'localhost';
     # mysql> GRANT ALL PRIVILEGES ON debug_toolbar.* TO 'debug_toolbar'@'localhost';
     DATABASES = {
         "default": {
@@ -95,23 +96,4 @@ if os.environ.get("DJANGO_DATABASE_ENGINE", "").lower() == "mysql":
         }
     }
 
-
-# django-debug-toolbar
-
-DEBUG_TOOLBAR_PANELS = [
-    "debug_toolbar.panels.versions.VersionsPanel",
-    "debug_toolbar.panels.timer.TimerPanel",
-    "debug_toolbar.panels.settings.SettingsPanel",
-    "debug_toolbar.panels.headers.HeadersPanel",
-    "debug_toolbar.panels.request.RequestPanel",
-    "debug_toolbar.panels.sql.SQLPanel",
-    "debug_toolbar.panels.templates.TemplatesPanel",
-    "debug_toolbar.panels.staticfiles.StaticFilesPanel",
-    "debug_toolbar.panels.cache.CachePanel",
-    "debug_toolbar.panels.signals.SignalsPanel",
-    "debug_toolbar.panels.logging.LoggingPanel",
-    "debug_toolbar.panels.redirects.RedirectsPanel",
-    "debug_toolbar.panels.profiling.ProfilingPanel",
-]
-
 STATICFILES_DIRS = [os.path.join(BASE_DIR, "example", "static")]
