@@ -1,5 +1,4 @@
-from __future__ import absolute_import, unicode_literals
-
+import io
 import sys
 import unittest
 
@@ -7,10 +6,13 @@ import django
 from django.contrib.auth.models import User
 from django.core import management
 from django.db import connection
-from django.db.backends import utils as db_backends_utils
 from django.test import TestCase
 from django.test.utils import override_settings
-from django.utils import six
+
+if connection.vendor == "postgresql" and django.VERSION >= (3, 0, 0):
+    from django.db.backends.postgresql import base as base_module
+else:
+    from django.db.backends import utils as base_module
 
 
 @override_settings(DEBUG=True)
@@ -20,7 +22,7 @@ from django.utils import six
 )
 class DebugSQLShellTestCase(TestCase):
     def setUp(self):
-        self.original_cursor_wrapper = db_backends_utils.CursorDebugWrapper
+        self.original_wrapper = base_module.CursorDebugWrapper
         # Since debugsqlshell monkey-patches django.db.backends.utils, we can
         # test it simply by loading it, without executing it. But we have to
         # undo the monkey-patch on exit.
@@ -29,10 +31,10 @@ class DebugSQLShellTestCase(TestCase):
         management.load_command_class(app_name, command_name)
 
     def tearDown(self):
-        db_backends_utils.CursorDebugWrapper = self.original_cursor_wrapper
+        base_module.CursorDebugWrapper = self.original_wrapper
 
     def test_command(self):
-        original_stdout, sys.stdout = sys.stdout, six.StringIO()
+        original_stdout, sys.stdout = sys.stdout, io.StringIO()
         try:
             User.objects.count()
             self.assertIn("SELECT COUNT", sys.stdout.getvalue())
