@@ -1,18 +1,15 @@
-# coding: utf-8
-
-from __future__ import absolute_import, unicode_literals
-
 import os
+import re
 import unittest
 
-import django
 import html5lib
 from django.contrib.staticfiles.testing import StaticLiveServerTestCase
 from django.core import signing
 from django.core.checks import Warning, run_checks
 from django.db import connection
+from django.http import HttpResponse
 from django.template.loader import get_template
-from django.test import RequestFactory, TestCase
+from django.test import RequestFactory, SimpleTestCase, TestCase
 from django.test.utils import override_settings
 
 from debug_toolbar.forms import SignedDataForm
@@ -50,9 +47,8 @@ class DebugToolbarTestCase(BaseTestCase):
         # takes stats from Request panel
         self.request.path = path
         panel = self.toolbar.get_panel_by_id("RequestPanel")
-        panel.process_request(self.request)
-        panel.process_response(self.request, self.response)
-        panel.generate_stats(self.request, self.response)
+        response = panel.process_request(self.request)
+        panel.generate_stats(self.request, response)
         return panel.get_stats()
 
     def test_url_resolving_positional(self):
@@ -79,22 +75,13 @@ class DebugToolbarTestCase(BaseTestCase):
         self.assertEqual(stats["view_kwargs"], "None")
         self.assertEqual(stats["view_func"], "<no view>")
 
-    # Django doesn't guarantee that process_request, process_view and
-    # process_response always get called in this order.
-
-    def test_middleware_view_only(self):
-        DebugToolbarMiddleware().process_view(
-            self.request, regular_view, ("title",), {}
-        )
-
-    def test_middleware_response_only(self):
-        DebugToolbarMiddleware().process_response(self.request, self.response)
-
     def test_middleware_response_insertion(self):
-        resp = regular_view(self.request, "İ")
-        DebugToolbarMiddleware().process_response(self.request, resp)
+        def get_response(request):
+            return regular_view(request, "İ")
+
+        response = DebugToolbarMiddleware(get_response)(self.request)
         # check toolbar insertion before "</body>"
-        self.assertContains(resp, "</div>\n</body>")
+        self.assertContains(response, "</div>\n</body>")
 
     def test_cache_page(self):
         self.client.get("/cached_view/")
@@ -108,6 +95,7 @@ class DebugToolbarIntegrationTestCase(TestCase):
     def test_middleware(self):
         response = self.client.get("/execute_sql/")
         self.assertEqual(response.status_code, 200)
+        self.assertContains(response, "djDebug")
 
     @override_settings(DEFAULT_CHARSET="iso-8859-1")
     def test_non_utf8_charset(self):
@@ -134,7 +122,10 @@ class DebugToolbarIntegrationTestCase(TestCase):
             raise self.failureException(msg)
 
     def test_render_panel_checks_show_toolbar(self):
-        toolbar = DebugToolbar(None)
+        def get_response(request):
+            return HttpResponse()
+
+        toolbar = DebugToolbar(rf.get("/"), get_response)
         toolbar.store()
         url = "/__debug__/render_panel/"
         data = {"store_id": toolbar.store_id, "panel_id": "VersionsPanel"}
@@ -299,6 +290,20 @@ class DebugToolbarIntegrationTestCase(TestCase):
         # Link to LOCATION header.
         self.assertIn(b'href="/regular/redirect/"', response.content)
 
+    def test_server_timing_headers(self):
+        response = self.client.get("/execute_sql/")
+        server_timing = response["Server-Timing"]
+        expected_partials = [
+            r'TimerPanel_utime;dur=(\d)*(\.(\d)*)?;desc="User CPU time", ',
+            r'TimerPanel_stime;dur=(\d)*(\.(\d)*)?;desc="System CPU time", ',
+            r'TimerPanel_total;dur=(\d)*(\.(\d)*)?;desc="Total CPU time", ',
+            r'TimerPanel_total_time;dur=(\d)*(\.(\d)*)?;desc="Elapsed time", ',
+            r'SQLPanel_sql_time;dur=(\d)*(\.(\d)*)?;desc="SQL 1 queries", ',
+            r'CachePanel_total_time;dur=0;desc="Cache 0 Calls"',
+        ]
+        for expected in expected_partials:
+            self.assertTrue(re.compile(expected).search(server_timing))
+
 
 @unittest.skipIf(webdriver is None, "selenium isn't installed")
 @unittest.skipUnless(
@@ -308,13 +313,13 @@ class DebugToolbarIntegrationTestCase(TestCase):
 class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
     @classmethod
     def setUpClass(cls):
-        super(DebugToolbarLiveTestCase, cls).setUpClass()
+        super().setUpClass()
         cls.selenium = webdriver.Firefox()
 
     @classmethod
     def tearDownClass(cls):
         cls.selenium.quit()
-        super(DebugToolbarLiveTestCase, cls).tearDownClass()
+        super().tearDownClass()
 
     def test_basic(self):
         self.selenium.get(self.live_server_url + "/regular/basic/")
@@ -404,11 +409,11 @@ class DebugToolbarLiveTestCase(StaticLiveServerTestCase):
 
 
 @override_settings(DEBUG=True)
-class DebugToolbarSystemChecksTestCase(BaseTestCase):
+class DebugToolbarSystemChecksTestCase(SimpleTestCase):
     @override_settings(
         MIDDLEWARE=[
-            "django.contrib.sessions.middleware.SessionMiddleware",
             "django.contrib.messages.middleware.MessageMiddleware",
+            "django.contrib.sessions.middleware.SessionMiddleware",
             "django.contrib.auth.middleware.AuthenticationMiddleware",
             "django.middleware.gzip.GZipMiddleware",
             "debug_toolbar.middleware.DebugToolbarMiddleware",
@@ -418,10 +423,10 @@ class DebugToolbarSystemChecksTestCase(BaseTestCase):
         messages = run_checks()
         self.assertEqual(messages, [])
 
-    @unittest.skipIf(django.VERSION >= (2, 2), "Django handles missing dirs itself.")
     @override_settings(
         MIDDLEWARE=[
             "django.contrib.messages.middleware.MessageMiddleware",
+            "django.contrib.sessions.middleware.SessionMiddleware",
             "django.contrib.auth.middleware.AuthenticationMiddleware",
         ]
     )
@@ -442,8 +447,8 @@ class DebugToolbarSystemChecksTestCase(BaseTestCase):
 
     @override_settings(
         MIDDLEWARE=[
-            "django.contrib.sessions.middleware.SessionMiddleware",
             "django.contrib.messages.middleware.MessageMiddleware",
+            "django.contrib.sessions.middleware.SessionMiddleware",
             "django.contrib.auth.middleware.AuthenticationMiddleware",
             "debug_toolbar.middleware.DebugToolbarMiddleware",
             "django.middleware.gzip.GZipMiddleware",
@@ -465,3 +470,23 @@ class DebugToolbarSystemChecksTestCase(BaseTestCase):
                 )
             ],
         )
+
+    @override_settings(
+        MIDDLEWARE_CLASSES=[
+            "django.contrib.messages.middleware.MessageMiddleware",
+            "django.contrib.sessions.middleware.SessionMiddleware",
+            "django.contrib.auth.middleware.AuthenticationMiddleware",
+            "django.middleware.gzip.GZipMiddleware",
+            "debug_toolbar.middleware.DebugToolbarMiddleware",
+        ]
+    )
+    def test_check_middleware_classes_error(self):
+        messages = run_checks()
+        self.assertIn(
+            Warning(
+                "debug_toolbar is incompatible with MIDDLEWARE_CLASSES setting.",
+                hint="Use MIDDLEWARE instead of MIDDLEWARE_CLASSES",
+                id="debug_toolbar.W004",
+            ),
+            messages,
+        )
