@@ -1,9 +1,5 @@
-# coding: utf-8
-
-from __future__ import absolute_import, unicode_literals
-
 from django.contrib.auth.models import User
-from django.http import HttpResponse, HttpResponseRedirect
+from django.http import HttpResponseRedirect
 from django.shortcuts import render
 from django.template.response import TemplateResponse
 from django.views.decorators.cache import cache_page
@@ -11,7 +7,7 @@ from django.views.decorators.cache import cache_page
 
 def execute_sql(request):
     list(User.objects.all())
-    return HttpResponse()
+    return render(request, "base.html")
 
 
 def regular_view(request, title):
@@ -29,12 +25,12 @@ def new_user(request, username="joe"):
 
 def resolving_view(request, arg1, arg2):
     # see test_url_resolving in tests.py
-    return HttpResponse()
+    return render(request, "base.html")
 
 
 @cache_page(60)
 def cached_view(request):
-    return HttpResponse()
+    return render(request, "base.html")
 
 
 def regular_jinjia_view(request, title):
